==> zio-aws-finspace_2.13-5.17.166.1-sources.jar: zio/aws/finspace/model/EnvironmentStatus.scala <==
package zio.aws.finspace.model
import scala.jdk.CollectionConverters._
sealed trait EnvironmentStatus {
  def unwrap: software.amazon.awssdk.services.finspace.model.EnvironmentStatus
}
object EnvironmentStatus {
  def wrap(
      value: software.amazon.awssdk.services.finspace.model.EnvironmentStatus
  ): zio.aws.finspace.model.EnvironmentStatus = value match {
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATE_REQUESTED =>
      val r = CREATE_REQUESTED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATING =>
      val r = CREATING
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATED =>
      val r = CREATED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETE_REQUESTED =>
      val r = DELETE_REQUESTED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETED =>
      val r = DELETED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_CREATION =>
      val r = FAILED_CREATION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.RETRY_DELETION =>
      val r = RETRY_DELETION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_DELETION =>
      val r = FAILED_DELETION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.SUSPENDED =>
      val r = SUSPENDED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object CREATE_REQUESTED
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATE_REQUESTED
  }
  case object CREATING extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATING
  }
  case object CREATED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATED
  }
  case object DELETE_REQUESTED
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETE_REQUESTED
  }
  case object DELETING extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETING
  }
  case object DELETED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETED
  }
  case object FAILED_CREATION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_CREATION
  }
  case object RETRY_DELETION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.RETRY_DELETION
  }
  case object FAILED_DELETION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_DELETION
  }
  case object SUSPENDED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.SUSPENDED
  }
}

==> zio-aws-finspace_2.13-6.20.149.2-sources.jar: zio/aws/finspace/model/EnvironmentStatus.scala <==
package zio.aws.finspace.model
import scala.jdk.CollectionConverters._
sealed trait EnvironmentStatus {
  def unwrap: software.amazon.awssdk.services.finspace.model.EnvironmentStatus
}
object EnvironmentStatus {
  def wrap(
      value: software.amazon.awssdk.services.finspace.model.EnvironmentStatus
  ): zio.aws.finspace.model.EnvironmentStatus = value match {
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATE_REQUESTED =>
      val r = CREATE_REQUESTED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATING =>
      val r = CREATING
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATED =>
      val r = CREATED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETE_REQUESTED =>
      val r = DELETE_REQUESTED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETING =>
      val r = DELETING
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETED =>
      val r = DELETED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_CREATION =>
      val r = FAILED_CREATION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.RETRY_DELETION =>
      val r = RETRY_DELETION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_DELETION =>
      val r = FAILED_DELETION
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UPDATE_NETWORK_REQUESTED =>
      val r = UPDATE_NETWORK_REQUESTED
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UPDATING_NETWORK =>
      val r = UPDATING_NETWORK
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_UPDATING_NETWORK =>
      val r = FAILED_UPDATING_NETWORK
      r
    case software.amazon.awssdk.services.finspace.model.EnvironmentStatus.SUSPENDED =>
      val r = SUSPENDED
      r
  }
  case object unknownToSdkVersion
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object CREATE_REQUESTED
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATE_REQUESTED
  }
  case object CREATING extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATING
  }
  case object CREATED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.CREATED
  }
  case object DELETE_REQUESTED
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETE_REQUESTED
  }
  case object DELETING extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETING
  }
  case object DELETED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.DELETED
  }
  case object FAILED_CREATION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_CREATION
  }
  case object RETRY_DELETION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.RETRY_DELETION
  }
  case object FAILED_DELETION extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_DELETION
  }
  case object UPDATE_NETWORK_REQUESTED
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UPDATE_NETWORK_REQUESTED
  }
  case object UPDATING_NETWORK
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.UPDATING_NETWORK
  }
  case object FAILED_UPDATING_NETWORK
      extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.FAILED_UPDATING_NETWORK
  }
  case object SUSPENDED extends zio.aws.finspace.model.EnvironmentStatus {
    override def unwrap
        : software.amazon.awssdk.services.finspace.model.EnvironmentStatus =
      software.amazon.awssdk.services.finspace.model.EnvironmentStatus.SUSPENDED
  }
}
